EXPORTS
	??0TASN1DecBitString@@QAE@XZ @ 1 NONAME ; public: __thiscall TASN1DecBitString::TASN1DecBitString(void)
	??0TASN1DecBoolean@@QAE@XZ @ 2 NONAME ; public: __thiscall TASN1DecBoolean::TASN1DecBoolean(void)
	??0TASN1DecGeneralString@@QAE@XZ @ 3 NONAME ; public: __thiscall TASN1DecGeneralString::TASN1DecGeneralString(void)
	??0TASN1DecGeneralizedTime@@QAE@XZ @ 4 NONAME ; public: __thiscall TASN1DecGeneralizedTime::TASN1DecGeneralizedTime(void)
	??0TASN1DecGeneric@@QAE@ABVTDesC8@@@Z @ 5 NONAME ; public: __thiscall TASN1DecGeneric::TASN1DecGeneric(class TDesC8 const &)
	??0TASN1DecGraphicString@@QAE@XZ @ 6 NONAME ; public: __thiscall TASN1DecGraphicString::TASN1DecGraphicString(void)
	??0TASN1DecIA5String@@QAE@XZ @ 7 NONAME ; public: __thiscall TASN1DecIA5String::TASN1DecIA5String(void)
	??0TASN1DecInteger@@QAE@XZ @ 8 NONAME ; public: __thiscall TASN1DecInteger::TASN1DecInteger(void)
	??0TASN1DecNull@@QAE@XZ @ 9 NONAME ; public: __thiscall TASN1DecNull::TASN1DecNull(void)
	??0TASN1DecNumericString@@QAE@XZ @ 10 NONAME ; public: __thiscall TASN1DecNumericString::TASN1DecNumericString(void)
	??0TASN1DecObjectIdentifier@@QAE@XZ @ 11 NONAME ; public: __thiscall TASN1DecObjectIdentifier::TASN1DecObjectIdentifier(void)
	??0TASN1DecOctetString@@QAE@XZ @ 12 NONAME ; public: __thiscall TASN1DecOctetString::TASN1DecOctetString(void)
	??0TASN1DecPrintableString@@QAE@XZ @ 13 NONAME ; public: __thiscall TASN1DecPrintableString::TASN1DecPrintableString(void)
	??0TASN1DecSequence@@QAE@XZ @ 14 NONAME ; public: __thiscall TASN1DecSequence::TASN1DecSequence(void)
	??0TASN1DecSet@@QAE@XZ @ 15 NONAME ; public: __thiscall TASN1DecSet::TASN1DecSet(void)
	??0TASN1DecTeletexString@@QAE@XZ @ 16 NONAME ; public: __thiscall TASN1DecTeletexString::TASN1DecTeletexString(void)
	??0TASN1DecUTCTime@@QAE@XZ @ 17 NONAME ; public: __thiscall TASN1DecUTCTime::TASN1DecUTCTime(void)
	??0TASN1DecVideotexString@@QAE@XZ @ 18 NONAME ; public: __thiscall TASN1DecVideotexString::TASN1DecVideotexString(void)
	??0TASN1DecVisibleString@@QAE@XZ @ 19 NONAME ; public: __thiscall TASN1DecVisibleString::TASN1DecVisibleString(void)
	?CheckValid@TASN1DecGeneralString@@IAEHABVTDesC8@@@Z @ 20 NONAME ; protected: int __thiscall TASN1DecGeneralString::CheckValid(class TDesC8 const &)
	?CheckValid@TASN1DecGraphicString@@IAEHABVTDesC8@@@Z @ 21 NONAME ; protected: int __thiscall TASN1DecGraphicString::CheckValid(class TDesC8 const &)
	?CheckValid@TASN1DecIA5String@@IAEHABVTDesC8@@@Z @ 22 NONAME ; protected: int __thiscall TASN1DecIA5String::CheckValid(class TDesC8 const &)
	?CheckValid@TASN1DecOctetString@@IAEHABVTDesC8@@@Z @ 23 NONAME ; protected: int __thiscall TASN1DecOctetString::CheckValid(class TDesC8 const &)
	?CheckValid@TASN1DecTeletexString@@IAEHABVTDesC8@@@Z @ 24 NONAME ; protected: int __thiscall TASN1DecTeletexString::CheckValid(class TDesC8 const &)
	?CheckValid@TASN1DecVideotexString@@IAEHABVTDesC8@@@Z @ 25 NONAME ; protected: int __thiscall TASN1DecVideotexString::CheckValid(class TDesC8 const &)
	?CheckValid@TASN1DecVisibleString@@IAEHABVTDesC8@@@Z @ 26 NONAME ; protected: int __thiscall TASN1DecVisibleString::CheckValid(class TDesC8 const &)
	?Class@TASN1DecGeneric@@QBE?AW4TASN1Class@@XZ @ 27 NONAME ; public: enum TASN1Class  __thiscall TASN1DecGeneric::Class(void)const 
	?DecodeDERL@TASN1DecBitString@@QAEPAVHBufC8@@ABVTASN1DecGeneric@@@Z @ 28 NONAME ; public: class HBufC8 * __thiscall TASN1DecBitString::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecBitString@@QAEPAVHBufC8@@ABVTDesC8@@AAH@Z @ 29 NONAME ; public: class HBufC8 * __thiscall TASN1DecBitString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecBoolean@@QAEHABVTASN1DecGeneric@@@Z @ 30 NONAME ; public: int __thiscall TASN1DecBoolean::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecBoolean@@QAEHABVTDesC8@@AAH@Z @ 31 NONAME ; public: int __thiscall TASN1DecBoolean::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecGeneralString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 32 NONAME ; public: class HBufC16 * __thiscall TASN1DecGeneralString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecGeneralizedTime@@QAE?AVTTime@@ABVTASN1DecGeneric@@@Z @ 33 NONAME ; public: class TTime  __thiscall TASN1DecGeneralizedTime::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecGeneralizedTime@@QAE?AVTTime@@ABVTDesC8@@AAH@Z @ 34 NONAME ; public: class TTime  __thiscall TASN1DecGeneralizedTime::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecGraphicString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 35 NONAME ; public: class HBufC16 * __thiscall TASN1DecGraphicString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecIA5String@@QAEPAVHBufC16@@ABVTASN1DecGeneric@@@Z @ 36 NONAME ; public: class HBufC16 * __thiscall TASN1DecIA5String::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecIA5String@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 37 NONAME ; public: class HBufC16 * __thiscall TASN1DecIA5String::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecNull@@QAEXABVTASN1DecGeneric@@@Z @ 38 NONAME ; public: void __thiscall TASN1DecNull::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecNull@@QAEXABVTDesC8@@AAH@Z @ 39 NONAME ; public: void __thiscall TASN1DecNull::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecNumericString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 40 NONAME ; public: class HBufC16 * __thiscall TASN1DecNumericString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecObjectIdentifier@@QAEPAVHBufC16@@ABVTASN1DecGeneric@@@Z @ 41 NONAME ; public: class HBufC16 * __thiscall TASN1DecObjectIdentifier::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecObjectIdentifier@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 42 NONAME ; public: class HBufC16 * __thiscall TASN1DecObjectIdentifier::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecOctetString@@QAEPAVHBufC8@@ABVTASN1DecGeneric@@@Z @ 43 NONAME ; public: class HBufC8 * __thiscall TASN1DecOctetString::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecOctetString@@QAEPAVHBufC8@@ABVTDesC8@@AAH@Z @ 44 NONAME ; public: class HBufC8 * __thiscall TASN1DecOctetString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecPrintableString@@QAEPAVHBufC16@@ABVTASN1DecGeneric@@@Z @ 45 NONAME ; public: class HBufC16 * __thiscall TASN1DecPrintableString::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecPrintableString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 46 NONAME ; public: class HBufC16 * __thiscall TASN1DecPrintableString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecTeletexString@@QAEPAVHBufC16@@ABVTASN1DecGeneric@@@Z @ 47 NONAME ; public: class HBufC16 * __thiscall TASN1DecTeletexString::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecTeletexString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 48 NONAME ; public: class HBufC16 * __thiscall TASN1DecTeletexString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecUTCTime@@QAE?AVTTime@@ABVTASN1DecGeneric@@@Z @ 49 NONAME ; public: class TTime  __thiscall TASN1DecUTCTime::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecUTCTime@@QAE?AVTTime@@ABVTDesC8@@AAH@Z @ 50 NONAME ; public: class TTime  __thiscall TASN1DecUTCTime::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecVideotexString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 51 NONAME ; public: class HBufC16 * __thiscall TASN1DecVideotexString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERL@TASN1DecVisibleString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 52 NONAME ; public: class HBufC16 * __thiscall TASN1DecVisibleString::DecodeDERL(class TDesC8 const &,int &)
	?DecodeDERLC@TASN1DecSequence@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTASN1DecGeneric@@@Z @ 53 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSequence::DecodeDERLC(class TASN1DecGeneric const &)
	?DecodeDERLC@TASN1DecSequence@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTASN1DecGeneric@@HH@Z @ 54 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSequence::DecodeDERLC(class TASN1DecGeneric const &,int,int)
	?DecodeDERLC@TASN1DecSequence@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTDesC8@@AAH@Z @ 55 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSequence::DecodeDERLC(class TDesC8 const &,int &)
	?DecodeDERLC@TASN1DecSequence@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTDesC8@@AAHHH@Z @ 56 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSequence::DecodeDERLC(class TDesC8 const &,int &,int,int)
	?DecodeDERLC@TASN1DecSet@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTASN1DecGeneric@@@Z @ 57 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSet::DecodeDERLC(class TASN1DecGeneric const &)
	?DecodeDERLC@TASN1DecSet@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTASN1DecGeneric@@HH@Z @ 58 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSet::DecodeDERLC(class TASN1DecGeneric const &,int,int)
	?DecodeDERLC@TASN1DecSet@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTDesC8@@AAH@Z @ 59 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSet::DecodeDERLC(class TDesC8 const &,int &)
	?DecodeDERLC@TASN1DecSet@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTDesC8@@AAHHH@Z @ 60 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSet::DecodeDERLC(class TDesC8 const &,int &,int,int)
	?DecodeDERLongL@TASN1DecInteger@@QAE?AVRInteger@@ABVTASN1DecGeneric@@@Z @ 61 NONAME ; public: class RInteger  __thiscall TASN1DecInteger::DecodeDERLongL(class TASN1DecGeneric const &)
	?DecodeDERLongL@TASN1DecInteger@@QAE?AVRInteger@@ABVTDesC8@@AAH@Z @ 62 NONAME ; public: class RInteger  __thiscall TASN1DecInteger::DecodeDERLongL(class TDesC8 const &,int &)
	?DecodeDERShortL@TASN1DecInteger@@QAEHABVTASN1DecGeneric@@@Z @ 63 NONAME ; public: int __thiscall TASN1DecInteger::DecodeDERShortL(class TASN1DecGeneric const &)
	?DecodeDERShortL@TASN1DecInteger@@QAEHABVTDesC8@@AAH@Z @ 64 NONAME ; public: int __thiscall TASN1DecInteger::DecodeDERShortL(class TDesC8 const &,int &)
	?Encoding@TASN1DecGeneric@@QBE?AVTPtrC8@@XZ @ 65 NONAME ; public: class TPtrC8  __thiscall TASN1DecGeneric::Encoding(void)const 
	?ExtractOctetStringL@TASN1DecBitString@@QAEPAVHBufC8@@ABVTASN1DecGeneric@@@Z @ 66 NONAME ; public: class HBufC8 * __thiscall TASN1DecBitString::ExtractOctetStringL(class TASN1DecGeneric const &)
	?ExtractOctetStringL@TASN1DecBitString@@QAEPAVHBufC8@@ABVTDesC8@@AAH@Z @ 67 NONAME ; public: class HBufC8 * __thiscall TASN1DecBitString::ExtractOctetStringL(class TDesC8 const &,int &)
	?GetContentDER@TASN1DecGeneric@@QBE?AVTPtrC8@@XZ @ 68 NONAME ; public: class TPtrC8  __thiscall TASN1DecGeneric::GetContentDER(void)const 
	?InitL@TASN1DecGeneric@@QAEXXZ @ 69 NONAME ; public: void __thiscall TASN1DecGeneric::InitL(void)
	?LengthDER@TASN1DecGeneric@@QBEHXZ @ 70 NONAME ; public: int __thiscall TASN1DecGeneric::LengthDER(void)const 
	?LengthDERContent@TASN1DecGeneric@@QBEHXZ @ 71 NONAME ; public: int __thiscall TASN1DecGeneric::LengthDERContent(void)const 
	?LengthDERHeader@TASN1DecGeneric@@QBEHXZ @ 72 NONAME ; public: int __thiscall TASN1DecGeneric::LengthDERHeader(void)const 
	?NewDERLC@TASN1DecSet@@QAEPAV?$CArrayPtrFlat@VTASN1DecGeneric@@@@ABVTDesC8@@@Z @ 73 NONAME ; public: class CArrayPtrFlat<class TASN1DecGeneric> * __thiscall TASN1DecSet::NewDERLC(class TDesC8 const &)
	?Tag@TASN1DecGeneric@@QBEIXZ @ 74 NONAME ; public: unsigned int __thiscall TASN1DecGeneric::Tag(void)const 
	??0TASN1DecUTF8String@@QAE@XZ @ 75 NONAME ; public: __thiscall TASN1DecUTF8String::TASN1DecUTF8String(void)
	?DecodeDERL@TASN1DecUTF8String@@QAEPAVHBufC16@@ABVTASN1DecGeneric@@@Z @ 76 NONAME ; public: class HBufC16 * __thiscall TASN1DecUTF8String::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecUTF8String@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 77 NONAME ; public: class HBufC16 * __thiscall TASN1DecUTF8String::DecodeDERL(class TDesC8 const &,int &)
	??0CASN1EncBase@@IAE@IW4TASN1Class@@@Z @ 78 NONAME ; protected: __thiscall CASN1EncBase::CASN1EncBase(unsigned int,enum TASN1Class)
	??0CASN1EncPrimitive@@IAE@I@Z @ 79 NONAME ; protected: __thiscall CASN1EncPrimitive::CASN1EncPrimitive(unsigned int)
	??1CASN1EncBase@@UAE@XZ @ 80 NONAME ; public: virtual __thiscall CASN1EncBase::~CASN1EncBase(void)
	??1CASN1EncBigInt@@UAE@XZ @ 81 NONAME ; public: virtual __thiscall CASN1EncBigInt::~CASN1EncBigInt(void)
	??1CASN1EncExplicitTag@@UAE@XZ @ 82 NONAME ; public: virtual __thiscall CASN1EncExplicitTag::~CASN1EncExplicitTag(void)
	??1CASN1EncObjectIdentifier@@UAE@XZ @ 83 NONAME ; public: virtual __thiscall CASN1EncObjectIdentifier::~CASN1EncObjectIdentifier(void)
	??1CASN1EncOctetString@@UAE@XZ @ 84 NONAME ; public: virtual __thiscall CASN1EncOctetString::~CASN1EncOctetString(void)
	??1CASN1EncSequence@@UAE@XZ @ 85 NONAME ; public: virtual __thiscall CASN1EncSequence::~CASN1EncSequence(void)
	?AddChildL@CASN1EncContainer@@QAEXPAVCASN1EncBase@@@Z @ 86 NONAME ; public: void __thiscall CASN1EncContainer::AddChildL(class CASN1EncBase *)
	?ConstructL@CASN1EncBase@@MAEXXZ @ 87 NONAME ; protected: virtual void __thiscall CASN1EncBase::ConstructL(void)
	?LengthDER@CASN1EncBase@@QBEIXZ @ 88 NONAME ; public: unsigned int __thiscall CASN1EncBase::LengthDER(void)const 
	?NewLC@CASN1EncBigInt@@SAPAV1@ABVTInteger@@@Z @ 89 NONAME ; public: static class CASN1EncBigInt * __cdecl CASN1EncBigInt::NewLC(class TInteger const &)
	?NewLC@CASN1EncBoolean@@SAPAV1@H@Z @ 90 NONAME ; public: static class CASN1EncBoolean * __cdecl CASN1EncBoolean::NewLC(int)
	?NewLC@CASN1EncExplicitTag@@SAPAV1@PAVCASN1EncBase@@IW4TASN1Class@@@Z @ 91 NONAME ; public: static class CASN1EncExplicitTag * __cdecl CASN1EncExplicitTag::NewLC(class CASN1EncBase *,unsigned int,enum TASN1Class)
	?NewLC@CASN1EncGeneralizedTime@@SAPAV1@ABVTTime@@@Z @ 92 NONAME ; public: static class CASN1EncGeneralizedTime * __cdecl CASN1EncGeneralizedTime::NewLC(class TTime const &)
	?NewLC@CASN1EncInt@@SAPAV1@H@Z @ 93 NONAME ; public: static class CASN1EncInt * __cdecl CASN1EncInt::NewLC(int)
	?NewLC@CASN1EncNull@@SAPAV1@XZ @ 94 NONAME ; public: static class CASN1EncNull * __cdecl CASN1EncNull::NewLC(void)
	?NewLC@CASN1EncObjectIdentifier@@SAPAV1@ABVTDesC16@@@Z @ 95 NONAME ; public: static class CASN1EncObjectIdentifier * __cdecl CASN1EncObjectIdentifier::NewLC(class TDesC16 const &)
	?NewLC@CASN1EncOctetString@@SAPAV1@ABVTDesC8@@@Z @ 96 NONAME ; public: static class CASN1EncOctetString * __cdecl CASN1EncOctetString::NewLC(class TDesC8 const &)
	?NewLC@CASN1EncSequence@@SAPAV1@XZ @ 97 NONAME ; public: static class CASN1EncSequence * __cdecl CASN1EncSequence::NewLC(void)
	?SetTag@CASN1EncBase@@QAEXIW4TASN1Class@@@Z @ 98 NONAME ; public: void __thiscall CASN1EncBase::SetTag(unsigned int,enum TASN1Class)
	?WriteDERL@CASN1EncBase@@QBEXAAVTDes8@@AAI@Z @ 99 NONAME ; public: void __thiscall CASN1EncBase::WriteDERL(class TDes8 &,unsigned int &)const 
	??0CASN1EncEncoding@@IAE@XZ @ 100 NONAME ; protected: __thiscall CASN1EncEncoding::CASN1EncEncoding(void)
	??1CASN1EncBitString@@UAE@XZ @ 101 NONAME ; public: virtual __thiscall CASN1EncBitString::~CASN1EncBitString(void)
	??1CASN1EncEncoding@@UAE@XZ @ 102 NONAME ; public: virtual __thiscall CASN1EncEncoding::~CASN1EncEncoding(void)
	?NewL@CASN1EncBigInt@@SAPAV1@ABVTInteger@@@Z @ 103 NONAME ; public: static class CASN1EncBigInt * __cdecl CASN1EncBigInt::NewL(class TInteger const &)
	?NewL@CASN1EncBitString@@SAPAV1@ABVCASN1EncBase@@@Z @ 104 NONAME ; public: static class CASN1EncBitString * __cdecl CASN1EncBitString::NewL(class CASN1EncBase const &)
	?NewL@CASN1EncBitString@@SAPAV1@ABVTDesC8@@@Z @ 105 NONAME ; public: static class CASN1EncBitString * __cdecl CASN1EncBitString::NewL(class TDesC8 const &)
	?NewL@CASN1EncBitString@@SAPAV1@ABVTDesC8@@I@Z @ 106 NONAME ; public: static class CASN1EncBitString * __cdecl CASN1EncBitString::NewL(class TDesC8 const &,unsigned int)
	?NewL@CASN1EncEncoding@@SAPAV1@ABVTDesC8@@@Z @ 107 NONAME ; public: static class CASN1EncEncoding * __cdecl CASN1EncEncoding::NewL(class TDesC8 const &)
	?NewLC@CASN1EncBitString@@SAPAV1@ABVCASN1EncBase@@@Z @ 108 NONAME ; public: static class CASN1EncBitString * __cdecl CASN1EncBitString::NewLC(class CASN1EncBase const &)
	?NewLC@CASN1EncBitString@@SAPAV1@ABVTDesC8@@@Z @ 109 NONAME ; public: static class CASN1EncBitString * __cdecl CASN1EncBitString::NewLC(class TDesC8 const &)
	?NewLC@CASN1EncBitString@@SAPAV1@ABVTDesC8@@I@Z @ 110 NONAME ; public: static class CASN1EncBitString * __cdecl CASN1EncBitString::NewLC(class TDesC8 const &,unsigned int)
	?NewLC@CASN1EncEncoding@@SAPAV1@ABVTDesC8@@@Z @ 111 NONAME ; public: static class CASN1EncEncoding * __cdecl CASN1EncEncoding::NewLC(class TDesC8 const &)
	?AddAndPopChildL@CASN1EncContainer@@QAEXPAVCASN1EncBase@@@Z @ 112 NONAME ; public: void __thiscall CASN1EncContainer::AddAndPopChildL(class CASN1EncBase *)
	?NewL@CASN1EncBoolean@@SAPAV1@H@Z @ 113 NONAME ; public: static class CASN1EncBoolean * __cdecl CASN1EncBoolean::NewL(int)
	?NewL@CASN1EncExplicitTag@@SAPAV1@PAVCASN1EncBase@@IW4TASN1Class@@@Z @ 114 NONAME ; public: static class CASN1EncExplicitTag * __cdecl CASN1EncExplicitTag::NewL(class CASN1EncBase *,unsigned int,enum TASN1Class)
	?NewL@CASN1EncGeneralizedTime@@SAPAV1@ABVTTime@@@Z @ 115 NONAME ; public: static class CASN1EncGeneralizedTime * __cdecl CASN1EncGeneralizedTime::NewL(class TTime const &)
	?NewL@CASN1EncInt@@SAPAV1@H@Z @ 116 NONAME ; public: static class CASN1EncInt * __cdecl CASN1EncInt::NewL(int)
	?NewL@CASN1EncNull@@SAPAV1@XZ @ 117 NONAME ; public: static class CASN1EncNull * __cdecl CASN1EncNull::NewL(void)
	?NewL@CASN1EncObjectIdentifier@@SAPAV1@ABVTDesC16@@@Z @ 118 NONAME ; public: static class CASN1EncObjectIdentifier * __cdecl CASN1EncObjectIdentifier::NewL(class TDesC16 const &)
	?NewL@CASN1EncOctetString@@SAPAV1@ABVTDesC8@@@Z @ 119 NONAME ; public: static class CASN1EncOctetString * __cdecl CASN1EncOctetString::NewL(class TDesC8 const &)
	?NewL@CASN1EncSequence@@SAPAV1@XZ @ 120 NONAME ; public: static class CASN1EncSequence * __cdecl CASN1EncSequence::NewL(void)
	??0TASN1DecBMPString@@QAE@XZ @ 121 NONAME ; TASN1DecBMPString::TASN1DecBMPString(void)
	?CheckValid@TASN1DecBMPString@@IAEHABVTDesC8@@@Z @ 122 NONAME ; int TASN1DecBMPString::CheckValid(class TDesC8 const &)
	?DecodeDERL@TASN1DecBMPString@@QAEPAVHBufC16@@ABVTASN1DecGeneric@@@Z @ 123 NONAME ; class HBufC16 * TASN1DecBMPString::DecodeDERL(class TASN1DecGeneric const &)
	?DecodeDERL@TASN1DecBMPString@@QAEPAVHBufC16@@ABVTDesC8@@AAH@Z @ 124 NONAME ; class HBufC16 * TASN1DecBMPString::DecodeDERL(class TDesC8 const &, int &)
	?NewLC@CASN1EncEncoding@@SAPAV1@ABVTDesC8@@IW4TASN1Class@@@Z @ 125 NONAME ; class CASN1EncEncoding * CASN1EncEncoding::NewLC(class TDesC8 const &, unsigned int, enum TASN1Class)
	??1CASN1EncSet@@UAE@XZ @ 126 NONAME ; CASN1EncSet::~CASN1EncSet(void)
	?NewL@CASN1EncSet@@SAPAV1@XZ @ 127 NONAME ; class CASN1EncSet * CASN1EncSet::NewL(void)
	?NewLC@CASN1EncSet@@SAPAV1@XZ @ 128 NONAME ; class CASN1EncSet * CASN1EncSet::NewLC(void)
	??1CASN1EncPrintableString@@UAE@XZ @ 129 NONAME ; CASN1EncPrintableString::~CASN1EncPrintableString(void)
	?NewL@CASN1EncPrintableString@@SAPAV1@ABVTDesC8@@@Z @ 130 NONAME ; class CASN1EncPrintableString * CASN1EncPrintableString::NewL(class TDesC8 const &)
	?NewLC@CASN1EncPrintableString@@SAPAV1@ABVTDesC8@@@Z @ 131 NONAME ; class CASN1EncPrintableString * CASN1EncPrintableString::NewLC(class TDesC8 const &)
	??0TASN1DecEnumerated@@QAE@XZ @ 132 NONAME ; TASN1DecEnumerated::TASN1DecEnumerated(void)

